@@ -76,11 +76,6 @@ def pytest_addoption(parser):
     parser.addoption("--hypothesis-benchmark-shrinks", type=str, choices=["new", "old"])
     parser.addoption("--hypothesis-benchmark-output", type=str)
 
-    # New in pytest 6, so we add a shim on old versions to avoid missing-arg errors
-    arg = "--durations-min"
-    if arg not in sum((a._long_opts for g in parser._groups for a in g.options), []):
-        parser.addoption(arg, action="store", default=1.0)
-
 
 @pytest.fixture(scope="function", params=["warns", "raises"])
 def warns_or_raises(request):
@@ -136,7 +131,7 @@ def allow_unknown_lambdas(monkeypatch):
 
 # monkeypatch is not thread-safe, so pytest-run-parallel will skip all our tests
 # if we define this.
-if settings._current_profile != "threading":
+if settings.get_current_profile_name() != "threading":
 
     @pytest.fixture(scope="function", autouse=True)
     def _consistently_increment_time(monkeypatch):
@@ -230,7 +225,7 @@ def pytest_runtest_call(item):
         not (hasattr(item, "obj") and is_hypothesis_test(item.obj))
         # we disable this check on the threading job, due to races in the global
         # state.
-        or settings._current_profile == "threading"
+        or settings.get_current_profile_name() == "threading"
     ):
         outcome = yield
     elif "pytest_randomly" in sys.modules:
